#!/bin/sh
rm -rf debian/tmp/gtk3/usr/share/icons/
rm -rf debian/tmp/gtk3/usr/share/locale/
rm -rf debian/tmp/gtk3/usr/share/mime/
rm -rf debian/tmp/gtk3/usr/share/spacefm/ui/
rm -rf debian/tmp/gtk3/usr/share/doc/
